# Svelte Web Components in Python

What if there was a way to just write `.svelte` files and import them in html like `.js` files?

Read the [documentation](https://panos-stavrianos.github.io/svelte_web_components/) to find out how to use it.

